/*+++
 *  title:      RTFDPane.m
 *  abstract:   Implementation of RTFDPane class for Pastry(1.2).
 *  author:     Tom Hageman <tom@basil.icce.rug.nl>
 *  created:    October 1994
 *  modified:   September 1997
 *  copyleft:
 *
 *		Copyright (C) 1994,1997  Tom R. Hageman.
 *
 *	This software is in the public domain.
 *
 *	This software is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 *  description:
 *
 *	This is an RTFD pane for Pastry.  I built it since Pastry 1.2's
 *	text inpector oddly enough does not handle RTFD.
 *
 *	THIS ONLY WORKS ON OPENSTEP/Mach 4.x!!!  It does not work on NEXTSTEP 3.x
 *	systems, apparently due to a bug in the Text object that's fixed in 4.x.
 *
 *	[I tried adding an .rtfd file that's loaded at initialization to prime
 *	 the text view, a workaround suggested by Jim Redman <jim@ergotech.com> 
 *	 for a similar problem, but unfortunately that didn't help.]
 *
 *---*/

#import "RTFDPane.h"

static NXAtom	types[2] = {NULL};

@implementation TRH_RTFDPane

- _loadNib
{
    char	buf[MAXPATHLEN+1];
    NXBundle	*bundle = [NXBundle bundleForClass:[self class]];

    // Load a nib file from the bundle
    [ bundle getPath:buf forResource:"RTFDPane" ofType:"nib"];

    [NXApp loadNibFile:buf
		 owner:self
	     withNames:NO
	      fromZone:[self zone]];

    view = [window setContentView:[[View alloc] init]];
    [window free];
    window = nil;
    return self;
}


+ initialize
{
    if (!types[0]) {
	types[0] = NXUniqueString("NeXT RTFD pasteboard type");
	// Hmmm. Apparently NeXT forgot to supply NXRTFDPboardType...
	types[1] = NULL;
    }
    return self;
}


+ (const NXAtom *)types
{
    return types;
}


- free
{
    [view free];
    return [super free];
}


- (View *)view
{
    if (!view)
	[self _loadNib];
    return view;
}


- updateFromStream:(NXStream *)stream withType:(NXAtom)type
{
    if (!view)
        [self _loadNib];

    if (![text readRTFDFrom: stream]) {
    	[text setText:"Cannot read RTFD from pasteboard!"]; // XXX Localization!
    }
    [text calcLine];	// Unclear from Class description if readRTFDFrom: already does this.
    return self;
}

- didSwapIn:sender
{
    [text calcLine];	// Seems like a good idea...
    [text sizeToFit];
    return self;
}

@end
